Enum diem_config::config::ContinuousSyncingMode [−][src]
pub enum ContinuousSyncingMode {
ExecuteTransactions,
ApplyTransactionOutputs,
}Expand description
The continuous syncing mode determines how the node will stay up-to-date once it has bootstrapped and the blockchain continues to grow, e.g., continuously executing all transactions.
Variants