Enum diem_config::config::ExecutionCorrectnessService [−][src]
pub enum ExecutionCorrectnessService {
Local,
Process(RemoteExecutionService),
Serializer,
Thread,
}Expand description
Defines how execution correctness should be run
Variants
This runs execution correctness in the same thread as event processor.
Process(RemoteExecutionService)This is the production, separate service approach
Tuple Fields of Process
This runs safety rules in the same thread as event processor but data is passed through the light weight RPC (serializer)
This creates a separate thread to run execution correctness, it is similar to a fork / exec style