Enum diem_config::config::PeerRole [−][src]
pub enum PeerRole {
Validator,
PreferredUpstream,
Upstream,
ValidatorFullNode,
Downstream,
Known,
Unknown,
}Expand description
Represents the Role that a peer plays in the network ecosystem rather than the type of node. Determines how nodes are connected to other nodes, and how discovery views them.
Rules for upstream nodes via Peer Role:
Validator -> Always upstream if not Validator else P2P PreferredUpstream -> Always upstream, overriding any other discovery ValidatorFullNode -> Always upstream for incoming connections (including other ValidatorFullNodes) Upstream -> Upstream, if no ValidatorFullNode or PreferredUpstream. Useful for initial seed discovery Downstream -> Downstream, defining a controlled downstream that I always want to connect Known -> A known peer, but it has no particular role assigned to it Unknown -> Undiscovered peer, likely due to a non-mutually authenticated connection always downstream
Variants