Enum diem_config::config::SafetyRulesService [−][src]
pub enum SafetyRulesService {
Local,
Process(RemoteService),
Serializer,
Thread,
}Expand description
Defines how safety rules should be executed
Variants
This runs safety rules in the same thread as event processor
Process(RemoteService)This is the production, separate service approach
Tuple Fields of Process
This runs safety rules in the same thread as event processor but data is passed through the light weight RPC (serializer)
This creates a separate thread to run safety rules, it is similar to a fork / exec style