Enum diem_config::config::Token [−][src]
Tokens can either be directly within this config or stored somewhere on disk.
Variants
FromConfig(String)Tuple Fields of FromConfig
0: StringFromDisk(PathBuf)This is an absolute path and not relative to data_dir
Tuple Fields of FromDisk
0: PathBufImplementations