Struct diem_config::config::KeyManagerConfig [−][src]
pub struct KeyManagerConfig {
pub logger: LoggerConfig,
pub json_rpc_endpoint: String,
pub rotation_period_secs: u64,
pub secure_backend: SecureBackend,
pub sleep_period_secs: u64,
pub txn_expiration_secs: u64,
pub chain_id: ChainId,
}Fields
logger: LoggerConfigjson_rpc_endpoint: Stringrotation_period_secs: u64secure_backend: SecureBackendsleep_period_secs: u64txn_expiration_secs: u64chain_id: ChainIdImplementations
Reads the key manager config file from the given input_path. Paths used in the config are either absolute or relative to the config location
Saves the key manager config file to the given output_path.