Struct diem_config::config::NodeConfig [−][src]
pub struct NodeConfig {Show 15 fields
pub base: BaseConfig,
pub consensus: ConsensusConfig,
pub debug_interface: DebugInterfaceConfig,
pub execution: ExecutionConfig,
pub full_node_networks: Vec<NetworkConfig>,
pub logger: LoggerConfig,
pub mempool: MempoolConfig,
pub metrics: DeprecatedConfig,
pub json_rpc: JsonRpcConfig,
pub api: ApiConfig,
pub state_sync: StateSyncConfig,
pub storage: StorageConfig,
pub test: Option<TestConfig>,
pub validator_network: Option<NetworkConfig>,
pub failpoints: Option<HashMap<String, String>>,
}Expand description
Config pulls in configuration information from the config file. This is used to set up the nodes and configure various parameters. The config file is broken up into sections for each module so that only that module can be passed around
Fields
base: BaseConfigconsensus: ConsensusConfigdebug_interface: DebugInterfaceConfigexecution: ExecutionConfigfull_node_networks: Vec<NetworkConfig>logger: LoggerConfigmempool: MempoolConfigmetrics: DeprecatedConfigjson_rpc: JsonRpcConfigapi: ApiConfigstate_sync: StateSyncConfigstorage: StorageConfigtest: Option<TestConfig>validator_network: Option<NetworkConfig>failpoints: Option<HashMap<String, String>>Implementations
Reads the config file and returns the configuration object in addition to doing some post-processing of the config Paths used in the config are either absolute or relative to the config location