Struct diem_config::config::OnDiskStorageConfig [−][src]
pub struct OnDiskStorageConfig {
pub path: PathBuf,
pub namespace: Option<String>,
// some fields omitted
}Fields
path: PathBufnamespace: Option<String>A namespace is an optional portion of the path to a key stored within OnDiskStorage. For example, a key, S, without a namespace would be available in S, with a namespace, N, it would be in N/S.
Implementations