Struct diem_config::config::Peer [−][src]
pub struct Peer {
pub addresses: Vec<NetworkAddress>,
pub keys: HashSet<PublicKey>,
pub role: PeerRole,
}Expand description
Represents a single seed configuration for a seed peer
Fields
addresses: Vec<NetworkAddress>keys: HashSet<PublicKey>role: PeerRoleImplementations
Combines Vec<NetworkAddress> keys with the HashSet given
Combines two Peer. Note: Does not merge duplicate addresses
TODO: Instead of rejecting, maybe pick one of the roles?