Struct diem_config::config::StateSyncDriverConfig [−][src]
pub struct StateSyncDriverConfig {
pub bootstrapping_mode: BootstrappingMode,
pub enable_state_sync_v2: bool,
pub continuous_syncing_mode: ContinuousSyncingMode,
pub progress_check_interval_ms: u64,
}Fields
bootstrapping_mode: BootstrappingModeenable_state_sync_v2: boolcontinuous_syncing_mode: ContinuousSyncingModeprogress_check_interval_ms: u64Trait Implementations
The default state sync driver config will be the one that gets (and keeps) the node up-to-date as quickly and cheaply as possible.
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.