Struct diem_config::config::StorageConfig[][src]

pub struct StorageConfig {
    pub address: SocketAddr,
    pub backup_service_address: SocketAddr,
    pub dir: PathBuf,
    pub grpc_max_receive_len: Option<i32>,
    pub prune_window: Option<u64>,
    pub timeout_ms: u64,
    pub rocksdb_config: RocksdbConfig,
    pub account_count_migration: bool,
    // some fields omitted
}

Fields

address: SocketAddrbackup_service_address: SocketAddrdir: PathBufgrpc_max_receive_len: Option<i32>prune_window: Option<u64>

None disables pruning. The windows is in number of versions, consider system tps (transaction per second) when calculating proper window.

timeout_ms: u64

Read, Write, Connect timeout for network operations in milliseconds

rocksdb_config: RocksdbConfig

Rocksdb-specific configurations

account_count_migration: bool

If enabled, leaf counts of the children of a JellyfishMerkelTree internal node are written down. This is supposed to be enabled after other aspects of the new release has been confirmed safe. And once enabled, an older node won’t be able to read the state DB, unless the DB is wiped and re-synced.

Implementations