Struct diem_config::config::VaultConfig[][src]

pub struct VaultConfig {
    pub ca_certificate: Option<PathBuf>,
    pub namespace: Option<String>,
    pub renew_ttl_secs: Option<u32>,
    pub server: String,
    pub token: Token,
    pub disable_cas: Option<bool>,
    pub connection_timeout_ms: Option<u64>,
    pub response_timeout_ms: Option<u64>,
}

Fields

ca_certificate: Option<PathBuf>

Optional SSL Certificate for the vault host, this is expected to be a full path.

namespace: Option<String>

A namespace is an optional portion of the path to a key stored within Vault. For example, a secret, S, without a namespace would be available in secret/data/S, with a namespace, N, it would be in secret/data/N/S.

renew_ttl_secs: Option<u32>

Vault leverages leases on many tokens, specify this to automatically have your lease renewed up to that many seconds more. If this is not specified, the lease will not automatically be renewed.

server: String

Vault’s URL, note: only HTTP is currently supported.

token: Token

The authorization token for accessing secrets

disable_cas: Option<bool>

Disable check-and-set when writing secrets to Vault

connection_timeout_ms: Option<u64>

Timeout for new vault socket connections, in milliseconds.

response_timeout_ms: Option<u64>

Timeout for generic vault operations (e.g., reads and writes), in milliseconds.

Implementations