Struct diem_config::config::GitHubConfig [−][src]
pub struct GitHubConfig {
pub repository_owner: String,
pub repository: String,
pub branch: Option<String>,
pub token: Token,
pub namespace: Option<String>,
}Fields
repository_owner: StringThe owner or account that hosts a repository
repository: StringThe repository where storage will mount
branch: Option<String>The branch containing storage, defaults to master
token: TokenThe authorization token for accessing the repository
namespace: Option<String>A namespace is an optional portion of the path to a key stored within GitHubConfig. For example, a key, S, without a namespace would be available in S, with a namespace, N, it would be in N/S.